summary refs log tree commit diff
path: root/pkgs/applications/editors/neovim/qt.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/applications/editors/neovim/qt.nix')
-rw-r--r--pkgs/applications/editors/neovim/qt.nix10
1 files changed, 5 insertions, 5 deletions
diff --git a/pkgs/applications/editors/neovim/qt.nix b/pkgs/applications/editors/neovim/qt.nix
index 48f7b29f407f..de217cb60f3f 100644
--- a/pkgs/applications/editors/neovim/qt.nix
+++ b/pkgs/applications/editors/neovim/qt.nix
@@ -1,5 +1,5 @@
 { stdenv, fetchFromGitHub, cmake, doxygen, makeWrapper
-, libmsgpack, neovim, pythonPackages, qtbase }:
+, msgpack, neovim, pythonPackages, qtbase }:
 
 stdenv.mkDerivation rec {
   name = "neovim-qt-${version}";
@@ -13,12 +13,12 @@ stdenv.mkDerivation rec {
   };
 
   cmakeFlags = [
-    "-DMSGPACK_INCLUDE_DIRS=${libmsgpack}/include"
-    "-DMSGPACK_LIBRARIES=${libmsgpack}/lib/libmsgpackc.so"
+    "-DMSGPACK_INCLUDE_DIRS=${msgpack}/include"
+    "-DMSGPACK_LIBRARIES=${msgpack}/lib/msgpackc.so"
   ];
 
   buildInputs = with pythonPackages; [
-    neovim qtbase libmsgpack
+    neovim qtbase msgpack
   ] ++ (with pythonPackages; [
     jinja2 msgpack python
   ]);
@@ -28,7 +28,7 @@ stdenv.mkDerivation rec {
   enableParallelBuilding = true;
 
   preConfigure = ''
     # avoid cmake trying to download libmsgpack
     echo "" > third-party/CMakeLists.txt
     # we rip out a number of tests that fail in the build env
     # the GUI tests will never work but the others should - they did before neovim 0.2.0
@@ -28,7 +28,7 @@ stdenv.mkDerivation rec {
 
   preConfigure = ''
-    # avoid cmake trying to download libmsgpack
+    # avoid cmake trying to download msgpack
     echo "" > third-party/CMakeLists.txt
     # we rip out a number of tests that fail in the build env